==> openshift-client-4.13.1-sources.jar: io/fabric8/openshift/client/dsl/internal/FeatureGateOperationsImpl.java <==

                
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.DoneableFeatureGate;
import io.fabric8.openshift.api.model.FeatureGate;
import io.fabric8.openshift.api.model.FeatureGateList;
import io.fabric8.openshift.api.model.DoneableFeatureGate;

import java.util.Map;
import java.util.TreeMap;


public class FeatureGateOperationsImpl extends OpenShiftOperation<FeatureGate, FeatureGateList, DoneableFeatureGate, Resource<FeatureGate, DoneableFeatureGate>> {

  public FeatureGateOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public FeatureGateOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("config.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("featuregates"));
    this.type = FeatureGate.class;
    this.listType = FeatureGateList.class;
    this.doneableType = DoneableFeatureGate.class;
  }

  public FeatureGateOperationsImpl newInstance(OperationContext context) {
    return new FeatureGateOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> openshift-client-5.3.1-sources.jar: io/fabric8/openshift/client/dsl/internal/FeatureGateOperationsImpl.java <==

                            
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.FeatureGate;
import io.fabric8.openshift.api.model.FeatureGateBuilder;
import io.fabric8.openshift.api.model.FeatureGateList;

import java.util.Map;
import java.util.TreeMap;


public class FeatureGateOperationsImpl extends OpenShiftOperation<FeatureGate, FeatureGateList, Resource<FeatureGate>> {

  public FeatureGateOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public FeatureGateOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("config.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("featuregates"));
    this.type = FeatureGate.class;
    this.listType = FeatureGateList.class;
  }

  public FeatureGateOperationsImpl newInstance(OperationContext context) {
    return new FeatureGateOperationsImpl(context);
  }

  @Override
  public FeatureGate edit(Visitor... visitors) {
    return patch(new FeatureGateBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
